@@ -371,10 +371,14 @@ class TestSpecifier:
                 # Test the greater than operation
                 ("3", ">2"),
                 ("2.1", ">2.0"),
+                ("2.0.1", ">2"),
+                ("2.1.post1", ">2"),
+                ("2.1+local.version", ">2"),
 
                 # Test the less than operation
                 ("1", "<2"),
                 ("2.0", "<2.1"),
+                ("2.0.dev0", "<2.1"),
 
                 # Test the compatibility operation
                 ("1", "~=1.0"),
@@ -467,7 +471,7 @@ class TestSpecifier:
                 ("2.0", ">2"),
                 ("2.0.post1", ">2"),
                 ("2.0.post1.dev1", ">2"),
-                ("2.0.1", ">2"),
+                ("2.0+local.version", ">2"),
 
                 # Test the less than operation
                 ("2.0.dev1", "<2"),
